#ifdef Z_SL_OPENGLES

	// --- Uniforms

	uniform highp mat4 u_ModelViewProjection;
	uniform highp mat4 u_ViewProjection;
	uniform highp mat4 u_ModelView;
	uniform highp mat4 u_Model;
	uniform lowp vec4 u_Colour;  
	uniform lowp sampler2D u_Texture;  

    uniform lowp float u_Dir;
    uniform highp vec2 u_PlayerPos;

	// --- Attributes
	
	#ifdef Z_SHADER_VERTEX 
		attribute highp vec4 a_Position;
		attribute lowp vec4 a_Colour;
		attribute highp vec2 a_TexCoords;
	#endif
		
	// --- Varyings
	
	varying lowp vec4 v_Colour;
	varying highp vec2 v_TexCoords;
		
	// --- Main
	
	#ifdef Z_SHADER_VERTEX

		void main()
		{
            vec4 worldPos = u_Model * a_Position;
            vec2 playerOffset = worldPos.xy - u_PlayerPos;

            // rotate playerOffset by 45 degrees:
            float cos45 = 0.70710678118;
            float sin45 = u_Dir * 0.70710678118;
            float x = playerOffset.x * cos45 - playerOffset.y * sin45;
            float y = playerOffset.x * sin45 + playerOffset.y * cos45;
            playerOffset = vec2(x, y);
            float t = abs(playerOffset.y);

            const float linStart = 75.0 * 1.41421356237;

            if (t < linStart)
            {

            }
            else
            {
                const float a = -3.99260e-14;
                const float b = 2.70067e-10;
                const float c = -7.04801e-07;
                const float d = 1.04233e-03;
                const float e = -1.00000e-01;

                t = mix((t - linStart) / (2500.0 - linStart), e + t * (d + t * (c + t * (b + t * a))), smoothstep(linStart, linStart + 15.0, t));

                if (playerOffset.y < -linStart)
                {
                    t = min(1.0, t * mix(1.0, 3.0, t));
                }

                const vec2 c0 = vec2(75.0, 75.0);
                const vec2 c1 = vec2(700.0, 700.0);
                const vec2 c2 = vec2(-1175.0, 375.0);
                const vec2 c3 = vec2(500.0, -350.0);

                float w = mix(1.0, 0.2, t * t * (3.0 - 2.0 * t));

                vec2 p = c0 + t * (c1 + t * (c2 + t * c3));
                p *= sign(playerOffset.y);
                p.x *= u_Dir;
                vec2 fwd = normalize(c1 + t * (2.0 * c2 + 3.0 * t * c3));
                fwd.x *= u_Dir;
                vec2 lft = vec2(fwd.y, -fwd.x);

                playerOffset = p + w * lft * playerOffset.x;
                worldPos = vec4(playerOffset + u_PlayerPos, worldPos.z, worldPos.w);
            }

			highp vec4 projPosition = u_ViewProjection * worldPos;
			gl_Position = projPosition;
			v_Colour = u_Colour * a_Colour;
			v_TexCoords = a_TexCoords;
		}
		
	#else

		void main()
		{
			lowp vec4 texValue = texture2D(u_Texture, v_TexCoords);
			gl_FragColor = v_Colour * texValue;
		}
		
	#endif
		
#endif